import time
import uuid

import pytest

from pscr_integration.api.org_retention_api import OrgRetentionApi
from pscr_integration.api.search_history_api import SearchHistoryAPI
from pscr_integration.search.searcher_factory import SearcherFactory
from pscr_integration.search.searcher_type import SearcherType


@pytest.fixture(scope="session")
def query_api(config, load_org_1):
    yield SearcherFactory.get_searcher(
        SearcherType.SERVICE,
        service_endpoint=config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
        org_id=load_org_1["loader"].org_id,
        device_id_start=load_org_1["loader"].device_id_start,
        device_id_end=load_org_1["loader"].device_id_end,
    )


@pytest.fixture(scope="session")
def search_history_api(config, load_org_1):
    api = SearchHistoryAPI(
        privatelink_hostname=config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
        org_key=load_org_1["loader"].org_id,
    )

    for saved_search in load_org_1["saved_searches"]:
        actual_saved_search = api.save_search(
            search_id=saved_search["id"],
            name=saved_search["name"],
            favorited=saved_search["favorited"],
            search_time=saved_search["search_time"],
            search_type=saved_search["type"],
            user_id=saved_search["user_id"],
            user_name=saved_search["user_name"],
            search_params=saved_search["search_params"],
        ).response
        assert saved_search["favorited"] or saved_search["id"] == actual_saved_search["id"]

        saved_search["id"] = actual_saved_search["id"]
        assert saved_search["user_name"] == actual_saved_search["user_name"]
        assert str(saved_search["user_id"]) == str(actual_saved_search["user_id"])

    yield {"api": api}

    for saved_search in load_org_1["saved_searches"]:
        delete_search_code = api.delete_search(saved_search["id"], user_id=saved_search["user_id"]).status_code

        # Code has been changed to a 200 instead of a 204, temporarily we
        # need to check for both
        assert delete_search_code == 204


@pytest.fixture(scope="session")
def org_retention_api(config, load_org_1):
    api = OrgRetentionApi(privatelink_hostname=config["env_vars"]["API_PRIVATELINK_HOSTNAME"])

    org1 = f"test_{str(uuid.uuid4()).replace('-', '')}"
    org1_default_retention = api.set_org_retention(org1, "default", 15)
    assert org1_default_retention == 15
    org1_longterm_retention = api.set_org_retention(org1, "longterm", 60)
    assert org1_longterm_retention == 60

    org2 = f"test_{str(uuid.uuid4()).replace('-', '')}"
    org2_default_retention = api.set_org_retention(org2, "default", 30)
    assert org2_default_retention == 30
    org2_longterm_retention = api.set_org_retention(org2, "longterm", 45)
    assert org2_longterm_retention == 45

    time.sleep(5)  # Short sleep to get around AWS list_bucket eventual consistency

    yield {
        "api": api,
        "retentions": {
            org1: {
                "default": org1_default_retention,
                "longterm": org1_longterm_retention,
            },
            org2: {
                "default": org2_default_retention,
                "longterm": org2_longterm_retention,
            },
        },
    }
