from typing import List, Optional

from pscr_integration.api.api_request import HTTPApiResponse
from pscr_integration.api.feed_api import FeedApi


class FeedApiV2(FeedApi):
    def create_feed(self, feedinfo: dict, reports: Optional[List[dict]] = None) -> HTTPApiResponse:
        params = {"feedinfo": feedinfo}
        if reports is not None:
            params.update(reports=reports)
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds", method="POST", params=params)

    def delete_feed(self, feed_id: str) -> HTTPApiResponse:
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}", method="DELETE")

    def get_feeds(self, include_public: Optional[bool] = None) -> HTTPApiResponse:
        return self._send_request(
            f"/feedmgr/v2/orgs/{self.org_id}/feeds",
            params={"include_public": include_public} if include_public else None,
        )

    def get_feed(self, feed_id: str) -> HTTPApiResponse:
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}")

    def get_feedinfo(self, feed_id: str) -> HTTPApiResponse:
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/feedinfo")

    def update_feedinfo(self, feed_id: str, feedinfo: dict) -> HTTPApiResponse:
        return self._send_request(
            f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/feedinfo",
            method="PUT",
            params=feedinfo,
        )

    def get_reports(self, feed_id: str) -> HTTPApiResponse:
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/reports")

    def get_report(self, feed_id: str, report_id: str) -> HTTPApiResponse:
        return self._send_request(f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/reports/{report_id}")

    def update_reports(self, feed_id: str, params: Optional[dict] = None) -> HTTPApiResponse:
        return self._send_request(
            f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/reports",
            method="POST",
            params=params,
        )

    def update_report(self, feed_id: str, report_id: str, report: dict) -> HTTPApiResponse:
        return self._send_request(
            f"/feedmgr/v2/orgs/{self.org_id}/feeds/{feed_id}/reports/{report_id}",
            method="PUT",
            params=report,
        )
