import os
from functools import partial
from typing import List, Optional

from pscr_integration.api.api_request import HTTPApiRequest, HTTPApiResponse
from pscr_integration.test_lifecycle.active_session import is_k8s


class FeedSearchAPI:
    def __init__(self, privatelink_hostname: str, org_id: str):
        self.org_id = org_id
        privatelink_hostname = os.environ.get("FEED_SEARCH_API_PRIVATELINK_HOSTNAME", privatelink_hostname)
        if is_k8s() and not privatelink_hostname:
            privatelink_hostname = "psc-lc-feed-search"
        url_prefix = "http://" + privatelink_hostname + ":5001"
        self._make_request = partial(HTTPApiRequest, org_id=org_id, url_prefix=url_prefix)

    def _send_request(self, route: str, params: dict, method: str = "GET") -> HTTPApiResponse:
        request = self._make_request()
        return request.send_request(route=route, method=method, params=params)

    def health_check(self) -> HTTPApiResponse:
        return self._send_request("/feedsearch/v1/health_check", params=None)

    def search(
        self,
        org_key: str,
        query: str,
        start: int = 0,
        rows: int = 10,
        sort: Optional[List[str]] = None,
        facet_field: Optional[List[str]] = None,
    ) -> HTTPApiResponse:
        params = {"query": query, "start": start, "rows": rows}
        if sort:
            params["sort"] = sort
        if facet_field:
            params["facet.field"] = facet_field

        return self._send_request(f"/feedsearch/v1/orgs/{org_key}/search", params=params)
