import os
from functools import partial
from typing import Dict

import requests

from pscr_integration.api.api_request import HTTPApiRequest
from pscr_integration.test_lifecycle.active_session import is_k8s


class OrgRetentionApi:
    def __init__(self, privatelink_hostname: str):
        privatelink_hostname = os.environ.get("ORG_RET_API_PRIVATELINK_HOSTNAME", privatelink_hostname)
        if is_k8s() and not privatelink_hostname:
            privatelink_hostname = "psc-lc-org-ret"
        self.url_prefix = "http://" + privatelink_hostname + ":5004"
        self._make_request = partial(HTTPApiRequest, url_prefix=self.url_prefix)

    def set_org_retention(self, org_key: str, retention_class: str, retention_days: int) -> int:
        params = {"retention_days": retention_days}
        request = self._make_request(org_id=org_key)

        resp = request.send_request(
            f"/retention/v1/orgs/{org_key}/classes/{retention_class}",
            method="PUT",
            params=params,
        )
        resp.raise_for_status()

        return resp.response["retention_days"]

    def get_org_retention(self, org_key: str, retention_class: str) -> int:
        request = self._make_request(org_id=org_key)
        resp = request.send_request(f"/retention/v1/orgs/{org_key}/classes/{retention_class}", method="GET")

        resp.raise_for_status()

        return resp.response["retention_days"]

    def get_org_retentions(self, org_key: str) -> Dict[str, int]:
        request = self._make_request(org_id=org_key)
        resp = request.send_request(f"/retention/v1/orgs/{org_key}/classes", method="GET")

        resp.raise_for_status()

        return resp.response

    def get_internal_all_retentions(self) -> Dict:
        resp = requests.get(f"{self.url_prefix}/internal/retention/v1/orgs", timeout=30)
        resp.raise_for_status()

        return resp.json()["retentions"]

    def get_internal_retention_defaults(self) -> Dict:
        resp = requests.get(f"{self.url_prefix}/internal/retention/v1/defaults", timeout=30)
        resp.raise_for_status()

        return resp.json()
