from typing import Optional, Dict
from uuid import uuid4

import pytest

from pscr_integration.api.api_request import HTTPApiResponse
from pscr_integration.api.watchlist_api import WatchlistApi
from pscr_integration.watchlists.watchlist import Watchlist


@pytest.mark.smoke_test
class WatchlistApiV2(WatchlistApi):
    def get_watchlists(self) -> HTTPApiResponse:
        return self._send_request("/watchlistmgr/v2/watchlist")

    def get_watchlist(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v2/watchlist/{watchlist_id}")

    def create_feed_watchlist(self, feed_id: str, name: Optional[str] = None) -> HTTPApiResponse:
        if name is None:
            name = str(uuid4())[:8]

        return self._send_request(
            "/watchlistmgr/v2/watchlist",
            method="POST",
            data={
                "name": f"{feed_id} Watchlist {name}",
                "description": f"Watchlist for feed {feed_id}",
                "classifier": {"key": "feed_id", "value": feed_id},
            },
        )

    def classifier_watchlist_to_watchlist(self, watchlist: Dict) -> Watchlist:
        return Watchlist(
            id=watchlist["id"],
            name=watchlist["name"],
            description=watchlist["description"],
            classifier_key=watchlist["classifier"]["key"],
            classifier_value=watchlist["classifier"]["value"],
            tags_enabled=watchlist["tags_enabled"],
            alerts_enabled=watchlist["alerts_enabled"],
        )
