from typing import Optional, List
from uuid import uuid4

import pytest

from pscr_integration.api.api_request import HTTPApiResponse
from pscr_integration.api.watchlist_api_v2 import WatchlistApiV2


@pytest.mark.smoke_test
class WatchlistApiV3(WatchlistApiV2):
    def get_watchlists(self) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists")

    def get_watchlist(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{watchlist_id}")

    def create_feed_watchlist(self, feed_id: str, name: Optional[str] = None) -> HTTPApiResponse:
        if name is None:
            name = str(uuid4())[:8]

        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists",
            method="POST",
            data={
                "name": f"{feed_id} Watchlist {name}",
                "description": f"Watchlist for feed {feed_id}",
                "classifier": {"key": "feed_id", "value": feed_id},
            },
        )

    def delete_watchlist(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{watchlist_id}",
            method="DELETE",
        )

    def get_watchlist_alert_status(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{watchlist_id}/alert")

    def add_watchlist_alert(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{watchlist_id}/alert",
            method="PUT",
        )

    def remove_watchlist_alert_status(self, watchlist_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{watchlist_id}/alert",
            method="DELETE",
        )

    def get_report_ignore(self, report_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/ignore")

    def get_report_ioc_ignore(self, report_id: str, ioc_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/iocs/{ioc_id}/ignore")

    def add_report_ignore(self, report_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/ignore",
            method="PUT",
        )

    def add_report_ioc_ignore(self, report_id: str, ioc_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/iocs/{ioc_id}/ignore",
            method="PUT",
        )

    def remove_report_ignore(self, report_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/ignore",
            method="DELETE",
        )

    def remove_report_ioc_ignore(self, report_id: str, ioc_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/iocs/{ioc_id}/ignore",
            method="DELETE",
        )

    def get_severity_overrides(self) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/reports/severity")

    def get_report_severity_override(self, report_id: str) -> HTTPApiResponse:
        return self._send_request(f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/severity")

    def set_report_severity_override(self, report_id: str, severity: int) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/severity",
            method="PUT",
            data={"severity": severity},
        )

    def remove_report_severity_override(self, report_id: str) -> HTTPApiResponse:
        return self._send_request(
            f"/watchlistmgr/v3/orgs/{self.org_id}/reports/{report_id}/severity",
            method="DELETE",
        )

    def get_watchlist_telemetry(self, watchlist_ids: List[str], intervals: List[int] = None) -> HTTPApiResponse:
        return self._send_request(
            f'/watchlistmgr/v3/orgs/{self.org_id}/watchlists/{",".join(watchlist_ids)}/telemetry',
            method="GET",
            params={"intervals": ",".join(str(interval) for interval in intervals)} if intervals else None,
        )
