import logging
from datetime import datetime, timedelta

from pscr_integration.kinesis import reader

_logger = logging.getLogger(__name__)


def get_k_stream_data(stream: str, expected_records: int) -> list:
    """check k stream records"""
    events = []
    records = reader.get_records(stream, expected_records)
    # wait for some mins to collect data
    timeout_time = datetime.now() + timedelta(seconds=120)
    for record in records:
        events.append(record)
        # Escape hatch, get_records is an iterator reading kinesis
        # and will wait until more records come or it times out
        if len(events) >= expected_records:
            break
        if datetime.now() >= timeout_time:
            _logger.warning("Timed out waiting for events records")
            break
        _logger.info("Still waiting , count so far: %s", len(events))

    return events
