import logging
import os
import time
import string
import random
import pytest
import boto3
from botocore.exceptions import ClientError

from pscr_integration.dre import kinesis_dre

_logger = logging.getLogger(__name__)

s3 = boto3.client("s3")
kinesis = boto3.client("kinesis")

test_stream = "ubs_test"

"""dre test"""


class TestDreOrg:
    @pytest.mark.skip("test is not robust")
    def test_dre(self, config):
        """test dre rule"""
        # create dre-c s3 dir in admin bucket and upload corresponding rule.json
        _logger.debug("Allow all: to collect some records")
        rule_file_name = "/dre_policies/allowAll.json"
        rule_file_path = self._get_file_path(rule_file_name)
        # bucket: ENV-admin-bucket
        # s3_path -> dre/rules.json:
        # dre -> file: dre_policies/rules.json

        admin_bucket = f"{config['env_vars']['ENV_NAME']}-pscr-admin-bucket"
        s3_file_path = "dre/rules.json"

        self._upload_s3_rule(rule_file_path, admin_bucket, s3_file_path)

        # 60s is rule update interval but the worst case can be
        # upload right after the dre rule loading from s3 so at least wait 60s
        # to take effect
        time.sleep(60)

        # check the stream records for count
        stream_name = f"{config['env_vars']['ENV_NAME']}__documents"
        records = kinesis_dre.get_k_stream_data(stream_name, 10)
        _logger.info("found %s records", len(records))
        assert len(records) >= 0

        drop_all_file_name = "/dre_policies/dropAll.json"
        drop_all_file_name_path = self._get_file_path(drop_all_file_name)
        self._upload_s3_rule(drop_all_file_name_path, admin_bucket, s3_file_path)
        time.sleep(60)

        _logger.debug("drop all records and expect no records ")
        new_records = kinesis_dre.get_k_stream_data(stream_name, 10)
        _logger.info("found %s records", len(new_records))
        assert len(new_records) <= len(records)

    @staticmethod
    def _get_file_path(rule_name):
        return os.path.dirname(os.path.abspath(__file__)) + rule_name

    @staticmethod
    def _upload_s3_rule(rule_file_path, admin_bucket, s3_file_path):
        """upload to s3"""
        try:
            s3.upload_file(rule_file_path, admin_bucket, s3_file_path)
        except ClientError as ex:
            _logger.error(
                "Failed to upload %s to s3://%s/%s: %s",
                rule_file_path,
                admin_bucket,
                s3_file_path,
                ex,
            )
        _logger.info("successfully upload the rules.json")

    @staticmethod
    def _get_random_alphanumeric_string(length: int = 7):
        letters_and_digits = string.ascii_letters + string.digits
        res_str = "".join((random.choice(letters_and_digits) for i in range(length)))
        return res_str

    def test_dre_dispatch(self, config):
        """
        :param config:
        :param dre_rule_update:
        :return:
        rule to dispatch all evnets to the target stream
        """
        # update rule in admin bucket
        admin_bucket = f"{config['env_vars']['ENV_NAME']}-pscr-admin-bucket"
        s3_file_path = "dre/rules.json"
        dispatch_rule_file_name = "/dre_policies/dispatch.json"
        dispatch_rule_file_path = self._get_file_path(dispatch_rule_file_name)
        self._upload_s3_rule(dispatch_rule_file_path, admin_bucket, s3_file_path)
        # 60s is rule update interval but the worst case can be
        # upload right after the dre rule loading from s3 so at least wait 60s
        # to take effect
        time.sleep(60)
        # dispatch to downstream kinesis and wait for data to be avaliable
        dispatch_stream_name = f"{config['env_vars']['ENV_NAME']}__{test_stream}"

        expected_records = kinesis_dre.get_k_stream_data(dispatch_stream_name, 20)
        count = len(expected_records)
        _logger.debug("expected count for target stream %s", count)
        assert count > 0
