import logging

import pytest

from pscr_integration.search.searcher_service import SearcherService
from pscr_integration.lc_services import LcServices

_logger = logging.getLogger(__name__)


@pytest.mark.skipif(
    LcServices.target_service() not in LcServices.feed_hit_services(),
    reason=f"Test is irrelevant for f{LcServices.target_service()}.",
)
class TestFeeds:
    def test_alarm_count(self, config, load_org_1):
        expected_alarm_count = config["config_file"]["test_constants"]["org1_alarm_count"]
        query = SearcherService(
            config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
            load_org_1["loader"].org_id,
            device_id_start=load_org_1["loader"].device_id_start,
            device_id_end=load_org_1["loader"].device_id_end,
        )
        result_count = query.count_query(180, "alert_id:*", expected_alarm_count, 0)
        assert result_count == expected_alarm_count

    @pytest.mark.skip(
        "Do not re-enable until we find an actual solution for the obscene delays in tag availability. "
        "'hey looks like it magically passes again' is not a solution"
    )
    @pytest.mark.smoke_test
    def test_tag_count(self, config, load_org_1):
        expected_tag_count = config["config_file"]["test_constants"]["org1_feed_hit_count"]
        query = SearcherService(
            config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
            load_org_1["loader"].org_id,
            device_id_start=load_org_1["loader"].device_id_start,
            device_id_end=load_org_1["loader"].device_id_end,
        )
        result_count = query.count_query(180, "report_id:*", expected_tag_count, 0)
        assert result_count == expected_tag_count
