import logging
import time
import pytest

from pscr_integration.api.search_api_v2 import SearchAPIV2
from pscr_integration.util import wait_until
from pscr_integration.test_lifecycle.active_session import is_kc
from pscr_integration.lc_services import LcServices

_logger = logging.getLogger(__name__)


@pytest.mark.smoke_test
@pytest.mark.skipif(
    not is_kc() or (LcServices.target_service() not in LcServices.nta_services()),
    reason=f"NTA tests run only against real envs or is irrelevant for f{LcServices.target_service()}",
)
@pytest.mark.skip(reason="Unblock smoke tests, need to investigate this")
class TestNtaStreaming:
    def test_nta_port_profiler(self, config, load_org_1):
        """Test that the llanta's port profiler is activated by the loaded data
        and the alert is correctly indexed in LC
        """

        v2 = SearchAPIV2(
            privatelink_hostname=config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
            org_id=load_org_1["loader"].org_id,
        )

        def get_results():
            v2_job_id = v2.create_observations_result(
                query=f"observation_type: NETWORK_TRAFFIC_ANALYSIS AND device_id: {load_org_1['loader'].nta_device_id}"
            ).response["job_id"]

            # wait_until v2 query gets data
            def get_v2_observations_data():
                v2_data = v2.get_observations_result(v2_job_id, row_count="10000000").response
                if v2_data["contacted"] == v2_data["completed"]:
                    return v2_data
                return False

            v2_data = wait_until(get_v2_observations_data, timeout=90, interval=30)

            return v2_data, v2_job_id

        v2_data, v2_job_id = get_results()
        retries = 0
        while v2_data and v2_data["num_found"] == 0:
            time.sleep(30)
            v2_data, v2_job_id = get_results()
            retries += 1

            if retries >= 3:
                break

        if not v2_data:
            pytest.fail(f"V2 observation search did not complete in 90 seconds. Job ID: {v2_job_id}")

        if v2_data["num_found"] == 0:
            pytest.fail(f"V2 query's num_found is 0 | Response: {v2_data}")

        v2_details_job_id = v2.create_observations_detail_result(
            [res["observation_id"] for res in v2_data["results"]]
        ).response["job_id"]

        # wait_until v2 query gets data
        def get_v2_observations_details():
            v2_details = v2.get_observations_detail_result(v2_details_job_id, row_count="10000000").response
            if v2_details["contacted"] == v2_details["completed"]:
                return v2_details
            return False

        v2_details = wait_until(get_v2_observations_details, timeout=90, interval=30)

        if not v2_details:
            pytest.fail(f"V2 observation details search did not complete in 90 seconds. Job ID: {v2_details_job_id}")

        if v2_details["num_found"] == 0:
            pytest.fail(f"V2 observation details query's num_found is 0 | Response: {v2_data}")

        for res in v2_details["results"]:
            assert res["network_traffic_analysis_identifier"] == "anomaly:serverportprofile_internal"
