import os
from typing import Any, AnyStr, Optional

from pscr_common.aws import get_boto3_client

from pscr_integration.test_lifecycle.active_session import Env

JSON = Any


# noinspection PyUnresolvedReferences
def _get_assume_role_sqs() -> "botocore.client.SQS":
    env_name = os.environ.get("ENV_NAME")
    mcs2_env_name = Env(commercial_name=env_name).kc_name
    mcs2_iam_role_arn = os.environ.get("MCS2_IAM_ROLE_ARN")
    if not mcs2_iam_role_arn:
        raise RuntimeError("Must provide MCS2_IAM_ROLE_ARN for role assume.")
    role_session_name = f"mcs2-app-{mcs2_env_name}-threathunter-smoke-role"

    sts = get_boto3_client("sts")
    assume_role_object = sts.assume_role(
        RoleArn=mcs2_iam_role_arn,
        RoleSessionName=role_session_name,
        DurationSeconds=900,
    )
    credentials = assume_role_object["Credentials"]
    return get_boto3_client(
        "sqs",
        aws_access_key_id=credentials["AccessKeyId"],
        aws_secret_access_key=credentials["SecretAccessKey"],
        aws_session_token=credentials["SessionToken"],
    )


def send_sqs(
    queue_name: AnyStr, message_body: AnyStr, assume_role: bool = False, message_attributes: Optional[JSON] = None
):
    sqs = get_boto3_client("sqs")
    if assume_role:
        sqs = _get_assume_role_sqs()

    queue_url = sqs.get_queue_url(QueueName=queue_name)["QueueUrl"]
    args = {"QueueUrl": queue_url, "MessageBody": message_body}
    if message_attributes:
        args.update({"MessageAttributes": message_attributes})
    sqs.send_message(QueueUrl=queue_url, MessageBody=message_body)
