import json
from typing import AnyStr

from pscr_integration.api.feed_api import FeedApi
from pscr_integration.api.watchlist_api import WatchlistApi
from pscr_integration.sqs.producer import send_sqs
from pscr_integration.test_lifecycle.active_session import is_kc
from pscr_integration.util import wait_until


def deprovision(clm_listener_sqs_queue: AnyStr, org_key: AnyStr, org_name: AnyStr):
    deprovisioning_message = json.dumps(
        {
            "Type": "Notification",
            "Message": json.dumps(
                {
                    "result": "SUCCESS",
                    "type": "DEREGISTER_PURGE",
                    "organization": {"org_key": org_key, "org_name": org_name},
                }
            ),
        }
    )

    send_sqs(queue_name=clm_listener_sqs_queue, message_body=deprovisioning_message, assume_role=is_kc())


def validate_deprovisioning(privatelink_hostname, org_key):
    feed_api = FeedApi(privatelink_hostname, org_key)
    watchlist_api = WatchlistApi(privatelink_hostname, org_key)

    def org_empty() -> bool:
        # Check feed/watchlist presence
        feeds = feed_api.get_feeds(include_public=False).response["results"]
        watchlists = watchlist_api.get_watchlists().response["results"]
        return all((len(feeds) == 0, len(watchlists) == 0))

    timeout_s = 300
    assert wait_until(
        condition=org_empty, timeout=timeout_s
    ), f"Org {org_key} was not deprovisioned within {timeout_s} seconds"
