import json
import logging
from datetime import datetime, timedelta

from pscr_integration.kinesis import reader

_logger = logging.getLogger(__name__)


def get_ubs_events(ubs_stream: str, org_id: str, expected_records: int) -> list:
    events = []
    records = reader.get_records(ubs_stream, expected_records)
    timeout_time = datetime.now() + timedelta(seconds=600)
    _logger.info(f"org_id: {org_id}")
    for record in records:
        event = json.loads(record)
        event_org_id = event["deviceMeta"]["orgId"]
        _logger.debug(f"alarm_org_id: {event_org_id}, passed_org_id: {org_id}")
        if event_org_id == org_id:
            events.append(event)
        else:
            _logger.debug("Found event not for this org")
        # Escape hatch, get_records is an iterator reading kinesis and will wait until more records come or it times out
        if len(events) >= expected_records:
            break
        if datetime.now() >= timeout_time:
            _logger.warning("Timed out waiting for UBS records")
            break
        _logger.info(f"Still waiting for all the records, count so far: {len(events)}")

    return events
