import logging
from datetime import datetime, timedelta

from google.protobuf.json_format import MessageToDict
from proto_proto_pscr.cb_psc_backend_event_batch_pb2 import CbAugmentedEventBatchMsg

from pscr_integration.kinesis import reader

_logger = logging.getLogger(__name__)


def get_uds_events(uds_stream_name: str, org_id: str, expected_records: int):
    events = []
    records = reader.get_records(uds_stream_name, decompress=False)
    timeout_time = datetime.now() + timedelta(seconds=600)

    for record in records:
        try:
            # parse protobuf
            event = CbAugmentedEventBatchMsg()
            event.ParseFromString(record)
            event = MessageToDict(event)

            if event["deviceMetadata"]["orgKey"] == org_id:
                events.append(event)
            else:
                _logger.debug("Found event not for this org")

        except Exception as e:
            _logger.info(f"Failed to parse protofbuf: {str(e)}")

        # Escape hatch, get_records is an iterator reading kinesis and will wait until more records come or it times out
        if len(events) >= expected_records:
            break
        if datetime.now() >= timeout_time:
            _logger.warning("Timed out waiting for UDS records")
            break
        _logger.info(f"Still waiting for all the UDS records, count so far: {len(events)}")

    return events
