import logging
import pytest

from pscr_integration.api.watchlist_api import WatchlistApi
from pscr_integration.search.searcher_service import SearcherService

_logger = logging.getLogger(__name__)


class TestWatchlists:
    @pytest.mark.skip("Disabled until fixed in: LC-566")
    def test_historical_tagging(self, config, load_org_1):
        expected_historical_tag_count = config["config_file"]["test_constants"]["org1_historical_feed_hit_count"]
        expected_process_count = config["config_file"]["test_constants"]["org1_process_count"]
        # 1. Wait for searcher stage 1
        query = SearcherService(
            config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
            load_org_1["loader"].org_id,
            device_id_start=load_org_1["loader"].device_id_start,
            device_id_end=load_org_1["loader"].device_id_end,
        )
        query.count_query(900, "-report_id:*", expected_process_count, 2)

        # 2. Subscribe to second feed
        watchlist_api = WatchlistApi(
            privatelink_hostname=config["env_vars"]["API_PRIVATELINK_HOSTNAME"],
            org_id=load_org_1["loader"].org_id,
        )
        watchlist_id = watchlist_api.create_feed_watchlist(load_org_1["feed_id_2"]).response["classifier"][
            "watchlist_id"
        ]
        assert watchlist_id

        report4_id = f'{load_org_1["feed_id_2"]}-report4'
        # 3. Historically tag documents
        assert query.historically_tag_feed(watchlist_id, report4_id)

        # 4. Check tag counts with a timeout
        result_count = query.count_query(
            120,
            f'report_id:"{report4_id}"',
            expected_historical_tag_count,
            refech_retries=60,
        )
        assert result_count == expected_historical_tag_count
